select distinct owner
from all_tables
order by owner
